@@ -5,6 +5,8 @@
 
 # change 'tests => 1' to 'tests => last_test_to_print';
 
+use strict;
+use warnings;
 use Test;
 BEGIN { plan tests => 3 };
 print "Trying to load required modules...       ";
@@ -20,15 +22,12 @@ ok(1); # If we made it this far, we're ok.
 
 print "Trying to process template with tt...    ";
 my $out = "";
-open F, "test/test1.out" or die $!;
-my $ref = join('',(<F>));
-close F;
 $tt->process("test/Templates/one",undef,\$out) || die $tt->error()."\n";
-#open F, ">test/test1.out" or die $!;
-#print F $out;
-#close F;
 ok(2);
 print "Comparing output with what's expected... ";
-die "Did not produce the expected output!" unless $out eq $ref;
+my $VAR1;
+$out = eval($out);
+die "Did not produce the expected output!" unless ($out->{'rdf:RDF'}->{'channel'}->{'title'} eq 'Slashdot: News for nerds, stuff that matters');
 ok(3);
 print "Seems like you are ready to rock and roll! :)\n";
+
